
 # [Description] Heatmap display of estimated gene-gene dependency    
 # [Author] Ryo Yoshida, University of Tokyo
 # [Last update] 14-03-2007 

 # Initialization for color setting 
	col.bg="grey96" # Background 
	rcol<-0	# RGB(r)
	gcol<-0	# RGB(g)
	bcol<-0	# RGB(b)

 # Generate read file name  
	file_data<-"data.txt"			# Name of data file
	file_set1<-"TRANS-MNET-EM.set"	# Name of parameter file 1 (icluding state dimension)
	file_set2<-"TRANS-MNET-GNET.set" 	# Name of parameter file 2 (including number of genes in each module)
	file_gnet<-"gnet_display.dat"		# Name of gene-gene interaction 
	file_module<-"module_display.dat"	# Name of gene expression patterns representative for the identified modules

 # Read data
	data<-read.delim(file_data,header=F)	# Read data file
	set1<-read.delim(file_set1,header=F) 	# Read parameter file 1 
	set2<-read.delim(file_set2,header=F)  	# Read parameter file 2 
	gnet<-read.delim(file_gnet,header=F)	# Read gene-gene interaction 
	module<-read.delim(file_module,header=F)	# Read expression patterns of transcriptional modules 

 # Data conversion 
	data<-as.matrix(data)				
	set1<-as.matrix(set1)
	set2<-as.matrix(set2)
	gnet<-as.matrix(gnet)
	module<-as.matrix(module)

	nummod<-as.numeric(set2[1,1])		# Number of genes in each module 
	dims<-as.numeric(set1[1,1])		# State dimension 


 # Observed time points  
	time<-data[2,2:dim(data)[2]]

 # Number of genes plotted 
	num<-nummod			# Number of genes which are plotted 
	if(num>20){num<-20}
	
 # Initial gene ID to be plotted 
	indgene<-c(2:(1+num))						# Gene IDs for the first positive module 
	indgene<-cbind(indgene,c((2+nummod):(1+nummod+num)))	# Gene IDs for the first negative module

 # Set gene IDs to be plotted (Top [num] genes are plotted for each module)
	for(i in 2:dims){
		strow1<-(i-1)*2*nummod+1
		strow2<-strow1+nummod
		indgene<-cbind(indgene,c((strow1+1):(strow1+num)))
		indgene<-cbind(indgene,c((strow2+1):(strow2+num)))
	}
	indgene<-as.vector(indgene)	# Column IDs corresponding to genes displayed 
	indgene2<-indgene+1		# Row IDs corresponding to genes displayed

 # Copy the gene-gene interaction onto x 
	x<-gnet[indgene,indgene2]
	x<-as.matrix(x)

 # Virtual axes for ensuring plot area 
	xaxis<-c(-10,(dim(x)[1]+10))
	yaxis<-xaxis

 # Marging parameters
	mrtop<- 0.2*length(xaxis)	# Top-side
	mrbot<- 0.2*length(xaxis)	# Bottom-side
	mrleft<- 0.3*length(xaxis)	# Left-side
	mrright<- 0.3*length(xaxis)	# Right-side

 # Create heatmap 
 	windows()		# Open device
 	plt=c(0.6,0.6,0.6,0.6)	# Margin parameter

 # Generate  empty image
 	plot(xaxis,yaxis,type="n",xlab="",ylab="",ann=FALSE,axes=FALSE)

 # Title 
 	title(sub="Estimated temporal relationships between genes relevant to the identified modules")	
 
 # Compute lower and upper bounds for heatmap color by using the 2nd and the 4th quantiles 
 	stat<-quantile(as.numeric(x))	# Compute quantiles  
 	llim<-stat[2]	# Lower value for heatmap color 
 	ulim<-stat[4]	# Upper value for heatmap color

 # Creat heatmap of gene interactions 
 	sp<-num*dims*2+2	# Top postion (y-axis) of the heatmap image
 	for(i in 1:dim(x)[1]){
 	for(j in 1:dim(x)[1]){
		if(as.numeric(x[i,j])>=0){			# If the estimated interaction is positive, ....
			ratio<-as.numeric(x[i,j])/ulim	
			if(ratio>=1){ratio<-1}			# Threashold at the upper bound
			rect(i,sp-j,i+1,sp-j-1,col=rgb(ratio,ratio,ratio))	
		}
		if(as.numeric(x[i,j])<0){			# If the estimated interaction is negative , ....
			ratio<-abs(as.numeric(x[i,j])/llim)
			if(ratio>=1){ratio<-1}			# Threashold at the upper bound
			rect(i,sp-j,i+1,sp-j-1,col=rgb(60/255,ratio,0))
		}
	
	}
 	}

 # Draw lines and module name

	# Color setting 
	col.line<-"cyan"		# Color for lines 
 	col.module<-"white"	# Color for 
 	col.text<-"black"		# Color for text

	 height<-num*dims*2	# Top postion (y-axis) of the heatmap image
	 width_poly<-4
	 center<- -0.8

 	for(i in 1:dims){
 
		strow1<-height-(i-1)*2*num+1	# Starting position for y-axis (module(+))
		strow2<-strow1-num		# Starting position for y-axis (module(-))

		strow3<-(i-1)*2*num+1		# Starting position for x-axis (module(+))
		strow4<-strow1+num		# Starting position for x-axis (module(-))

		segments(1,strow1,1+height,strow1,col=col.line)		# Draw line along with y-axis (module(+)) 
		segments(1,strow2,1+height,strow2,col=col.line)		# Draw line along with y-axis (module(-))
		segments(strow1,1+height,strow1,1,col=col.line)		# Draw line along with x-axis (module(+))
		segments(strow2,1+height,strow2,1,col=col.line)		# Draw line along with x-axis (module(-))

		polygon(c(strow1-num,strow1-num,strow1,strow1),c(-width_poly,1,1,-width_poly),col=col.module)		# Draw rectangle for module(+) at top side margin 
		polygon(c(strow2-num,strow2-num,strow2,strow2),c(-width_poly,1,1,-width_poly),col=col.module)		# Draw rectangle for module(-) at top side margin 
		polygon(c(- width_poly,1,1,-width_poly),c(strow1-num,strow1-num,strow1,strow1),col=col.module)		# Draw rectangle for module(+) at left side margin 
		polygon(c(- width_poly,1,1,-width_poly),c(strow2-num,strow2-num,strow2,strow2),col=col.module)		# Draw rectangle for module(-) at left side margin 


		# Draw module ID at the margin spaces  
		ax1<-strow1-num/2
		ax2<-strow2-num/2
		ax3<-strow3+num/2
		ax4<-strow4+num/2
		text(center,ax1,paste("M-",i,"(+)",sep=""),srt=90,adj=0.5,font=2,cex=0.7,col=col.text)	
		text(center,ax2,paste("M-",i,"(-)",sep=""),srt=90,adj=0.5,font=2,cex=0.7,col=col.text)
		text(ax1,center,paste("M-",(dims-i+1),"(-)",sep=""),adj=0.5,font=2,cex=0.7,col=col.text)
		text(ax2,center,paste("M-",(dims-i+1),"(+)",sep=""),adj=0.5,font=2,cex=0.7,col=col.text)

 	}


	# Draw time IDs
 	loc1<- -7	
 	loc2<-num*dims
 	text(loc2,loc1,"Previous Time",adj=0.5,font=2,cex=0.9,col=col.text)
	text(loc1,loc2,"Cuurent Time",srt=90,adj=0.5,font=2,cex=0.9,col=col.text)

 

 # Create description window 
	
	windows() 
	xaxis<-c(1:100) 
	yaxis<-xaxis
	plot(xaxis,yaxis,type="n",xlab="",ylab="",ann=FALSE,axes=FALSE)
	text(1,100,"*** Description *** ",adj=0,font=2,cex=0.9,col=col.text)
	text(1,96,"# Heatmap image for the estimated tempotal structure",adj=0,font=2,cex=0.9,col=col.text)
	text(1,92,"# Color bar",adj=0,font=2,cex=0.9,col=col.text)
	cols<-c(255,153,51,0,51,153,255)
	for(i in 1:7){
		if(i>=4){rect(10+(i-1)*12,80,10+i*12,85,col=rgb(cols[i]/255,cols[i]/255,cols[i]/255))}
		if(i<4){rect(10+(i-1)*12,80,10+i*12,85,col=rgb(60/255,cols[i]/255,0))}
	}
	text(10,87,"(-)",adj=0,font=2,cex=0.9,col=col.text)
	text(10+7*12-3,87.5,"(+)",adj=0,font=2,cex=0.9,col=col.text)	
	text(10+(7*12)/2,87.5,"0",adj=0,font=2,cex=0.9,col=col.text)

	text(1,75," ",adj=0,font=2,cex=0.9,col=col.text)
	text(3,71,"# Each pixel represents the estimated causal relationship ",adj=0,font=2,cex=0.9,col=col.text)
	text(3,67,"  between a pair of genes across the successive time points.",adj=0,font=2,cex=0.9,col=col.text)
	text(3,63,"# For each module, the most representative genes are " ,adj=0,font=2,cex=0.9,col=col.text)
	text(3,59,"  displayed at here.",adj=0,font=2,cex=0.9,col=col.text)
	text(3,55,"# The number of genes displayed can be selected by excecuting ",adj=0,font=2,cex=0.9,col="red")
	text(3,51,"  TRANS-MNET-GENT.exe after specifying it on TRANS-MNET-GENT.set. ",adj=0,font=2,cex=0.9,col="red")
	text(3,47,"# Read file: gnet_display.dat",adj=0,font=2,cex=0.9,col="black")
	text(3,43,"# Module label: M-[module ID]-[sign]",adj=0,font=2,cex=0.9,col="black")
	text(3,39,"# Gene names in the indentified transcriptional modules",adj=0,font=2,cex=0.9,col="black")
	text(3,35,"  can be addressed under gnet_display.dat.",adj=0,font=2,cex=0.9,col="black")
	text(3,31,"# Currently, the number of genes displayed for each module",adj=0,font=2,cex=0.9,col="red")
	text(3,27,"  is limited by 20 (15-March-2007).",adj=0,font=2,cex=0.9,col="red")




 # Creat gene name windows 
	
	name<-c()
	for(i in 1:(2*dims)){
		id<-indgene[(num*(i-1)+1):(num*(i-1)+num)]
		name<-cbind(name,as.character(gnet[id,2]))	
	}

	Module.ID<-c()
	emp<-c()
	ic<-0
	for(i in 1:dims){
		ic<-ic+1
		Module.ID[ic]<-paste("M-",i,"(+)",sep="")
		emp[ic]<-"###"
		ic<-ic+1
		Module.ID[ic]<-paste("M-",i,"(-)",sep="")
		emp[ic]<-"###"
	}


	#name<-rbind(emp,name)
	name<-rbind(Module.ID,name)
	name
	name<-edit(name)
	#print("Gene List")
	#data.frame(name)

