

 # [Description] Heatmap display of estimated gene-gene dependency    
 # [Author] Ryo Yoshida, University of Tokyo
 # [Last update] 15-03-2007 


 # Target gene name 
	trg<-"420" 
	npa<-5
	nch<-10


# Function for drawing causal graph 
 
 graph.tmnet<-function(trg,npa,nch,plt.ch=TRUE,plt.pa=TRUE){	

 # Color setting 
	col.bg="grey96" 	# Background 
	rcol<-0	# RGB(r)
	gcol<-0	# RGB(g)
	bcol<-0	# RGB(b)

 # Generate read file name  
	file_gnet<-"gnet_display.dat"

 # Read data
	gnet<-read.delim(file_gnet,header=F) 
	gnet<-as.matrix(gnet)

 # Target gene ID 
	id<-0
	for(i in 1:dim(gnet)[1]){
		if(gnet[i,2]==trg){id<-i}
	}
	
	pa<-gnet[id,3:dim(gnet)[2]]	# Parent
	ch<-gnet[2:dim(gnet)[1],id]	# Children 
	lstpa<-order(pa)			# Ordered list of parent
	lstch<-order(ch)			# Ordered list of children 

	pospa<-lstpa[(length(lstpa)-npa+1):length(lstpa)]	# Most relevant activators (parent)
	negpa<-lstpa[1:npa]						# Most relevant repressors (parent)
	lbpospa<-gnet[1+pospa,2]					# Most relevant regulon
	lbnegpa<-gnet[1+negpa,2]
	
	posch<-lstpa[(length(lstch)-nch+1):length(lstch)]
	negch<-lstpa[1:nch]	
	lbposch<-gnet[1+posch,2]
	lbnegch<-gnet[1+negch,2]


# Drawing causal graph

	windows()
	v<-seq(0,2*pi-2*pi/50,length=50)
	xloc<-100*cos(v)
	yloc<-100*sin(v)
	plot(xloc,yloc,col="red",xlim=c(-150,150),ylim=c(-150,150),type="n",ann=FALSE,axes=FALSE)
	title(sub="Highly cennected genes")	# Title
	points(0,0,pch=19,col="mediumorchid",cex=1)
	text(0,10,trg,cex=1.0,adj=0.5,col="black",font=2)
	
	ang<-seq(0+2*pi/8,2*pi-2*pi/4+2*pi/8,length=4)
	cntx<-100*cos(ang)
	cnty<-100*sin(ang)
	#points(cntx,cnty,pch=19,col="black",cex=1)

	tch<-0.3
	rym<-120
	size.text<-0.8	
	shf<-5
	shf2<-10

	if(plt.pa==TRUE){
	# Activators (parent) of target gene 
	ang2<-seq(pi+tch,3*pi/2-tch,length=npa)
	xloc<-rym*cos(ang2)
	yloc<-rym*sin(ang2)
	points(150+xloc,150+yloc,pch=19,col="black",cex=1)
	text(150+xloc+shf,150+yloc+shf,lbpospa,srt=45,cex=size.text,adj=0,col="black",font=2)
	cnt<-rep(0,length=length(yloc))
	for(i in 1:npa){arrows(cnt[i],cnt[i],(150+xloc[i]),(150+yloc[i]),code=1,col="red",lwd=1,length=0.1)}

	# Repressor (parent) of target gene 
	ang2<-seq(3*pi/2+tch,2*pi-tch,length=npa)
	xloc<-rym*cos(ang2)
	yloc<-rym*sin(ang2)
	points(-150+xloc,150+yloc,pch=19,col="black",cex=1)
	text(-150+xloc-shf,150+yloc+shf,lbnegpa,srt=-45,cex=size.text,adj=1,col="black",font=2)
	cnt<-rep(0,length=length(yloc))
	for(i in 1:npa){arrows(cnt[i],cnt[i],(-150+xloc[i]),(150+yloc[i]),code=1,col="darkgreen",lwd=1,length=0.1)}
	
	}
	
	if(plt.ch==TRUE){	
	# genes (child) repressed by target gene 
	ang2<-seq(tch,pi/2-tch,length=nch)
	xloc<-rym*cos(ang2)
	yloc<-rym*sin(ang2)
	points(-150+xloc,-150+yloc,pch=19,col="black",cex=1)
	text(-150+xloc-shf,-150+yloc-shf2,lbnegch,srt=45,cex=size.text,adj=1,col="black",font=2)
	cnt<-rep(0,length=length(yloc))
	for(i in 1:nch){arrows((-150+xloc[i]),(-150+yloc[i]),cnt[i],cnt[i],code=1,col="darkgreen",lwd=1,length=0.1)}

	# genes (parent) activated by target gene 
	ang2<-seq(pi/2+tch,pi-tch,length=nch)
	xloc<-rym*cos(ang2)
	yloc<-rym*sin(ang2)
	points(150+xloc,-150+yloc,pch=19,col="black",cex=1)
	text(150+xloc+shf,-150+yloc-shf,lbnegpa,srt=-45,cex=size.text,adj=0,col="black",font=2)
	cnt<-rep(0,length=length(yloc))
	for(i in 1:nch){arrows((150+xloc[i]),(-150+yloc[i]),cnt[i],cnt[i],code=1,col="red",lwd=1,length=0.1)}
	
	}

	lbloc<-60
	if(plt.pa==TRUE){
		text(lbloc,lbloc,"Parent.Set (Activators)",srt=-45,cex=0.8,adj=0.5,col="black",font=2)
		text(-lbloc,lbloc,"Parent.Set (Repressors)",srt=45,cex=0.8,adj=0.5,col="black",font=2)
	}
	if(plt.ch==TRUE){
		text(-lbloc,-lbloc,"Child.Set (Repressors)",srt=-45,cex=0.8,adj=0.5,col="black",font=2)
		text(lbloc,-lbloc,"Child.Set (Activators)",srt=45,cex=0.8,adj=0.5,col="black",font=2)
	}

} # End Function


