
 # [Description] Heatmap display of indentified transcriptional modules    
 # [Author] Ryo Yoshida, University of Tokyo
 # [Last update] 13-03-2007 

 # Color setting 
	col.bg="grey96" # Background 
	rcol<-0	# RGB(r)
	gcol<-0	# RGB(g)
	bcol<-0	# RGB(b)

 # Generate read file name  
	file_data<-"data.txt"			# Data file
	file_set1<-"TRANS-MNET-EM.set"	# State dimension 
	file_set2<-"TRANS-MNET-GNET.set" 
	file_module<-"module_display.dat"

 # Read data
	data<-read.delim(file_data,header=F)		# Data file
	set1<-read.delim(file_set1,header=F) 	# State dimension 
	set2<-read.delim(file_set2,header=F)  
	module<-read.delim(file_module,header=F)		# Expression patterns of transcriptional modules 

	data<-as.matrix(data)
	set1<-as.matrix(set1)
	set2<-as.matrix(set2)
	module<-as.matrix(module)	

	nummod<-as.numeric(set2[1,1])
	dims<-as.numeric(set1[1,1])

# Observed time points  
	time<-data[2,2:dim(data)[2]]

# Computation of maximum and minimum intensities of transcriptional modules
	ulim<-max(as.numeric(module[3:dim(module)[1],3:dim(module)[2]]))		# Upper bound 
	llim<-min(as.numeric(module[3:dim(module)[1],3:dim(module)[2]]))		# Lower bound 

# Virtual vector for creating plot region 
	xaxis<-c(1:nummod)
	yaxis<-seq(0,length(time)*3,length=length(xaxis))

# Margin 
	mrtop<- 0.2*length(time)	# Top-side margin
	mrbot<- 0.2*length(time)	# Bottom-side margin 
	mrleft<- 0.3*length(xaxis)	# Left-side margin
	mrright<- 0.3*length(xaxis)	# Right-side margin

# Loop for plotting the heatmap of expression pattern for each transcriptional module

 for(i in 1:dims){
	windows()	# Open a new device  
	strow1<-(i-1)*2*nummod+2		# Start position of positive module
	strow2<-strow1+nummod		# Start position of negative module
	plt=c(0,1,0,1)				# Plot margin parameter

	# Plot empty image
		plot(xaxis,yaxis,type="n",xlab="",ylab="",ann=FALSE,axes=FALSE)
	# Plot title 	
		title(main=paste("Identified Transcriptional Module"," ",i,sep=""),
			sub="(+) and (-) modules are displayed at top and bottom panels.")
	# Background 
		rect(1-mrleft,0-mrbot,length(xaxis)+mrright,3.0*length(time)+mrtop,col=col.bg)
	# Label of y-axis (Time.Point)
		text(-mrleft,2.7*length(time),"Time.Point",srt=0,adj=0,cex=0.5,font=4)
	
	# Write time points
	for(k in 1:length(time)){
		text(-1,2.7*length(time)-k-0.5,time[k],srt=0,adj=0.5,cex=0.5,font=4)
		text(-1,length(time)-k-0.5,time[k],srt=0,adj=0.5,cex=0.5,font=4)
	}

	# Loop for drawing pixel and gene name 
	for(j in 1:nummod){
		vps<-as.numeric(module[strow1+j,3:dim(module)[2]])	# Intensity vector of positive module gene
		vng<-as.numeric(module[strow2+j,3:dim(module)[2]])	# Intensity vector of negative module gene 
		ulimps<-max(vps)		# Upper bound for intensity vector of positive module gene
		llimps<-min(vps)		# Lower bound for intensity vector of positive module gene
		ulimng<-max(vng)		# Upper bound for intensity vector of negative module gene
		llimng<-min(vng)		# Lower bound for intensity vector of positive module gene
		text(j+0.5,2.7*length(time),module[strow1+j,2],srt=90,adj=0,cex=0.5,font=4)	# Plot gene name (positive set)
		text(j+0.5,length(time),module[strow2+j+0.5,2],srt=90,adj=0,cex=0.5,font=4)	# Plot gene name (negative set)
	
			for(k in 1:length(time)){
				if(as.numeric(module[strow1+j,2+k])>=0){ratiops<-as.numeric(module[strow1+j,2+k])/ulimps} 
				if(as.numeric(module[strow1+j,2+k])<0){ratiops<-abs(as.numeric(module[strow1+j,2+k])/llimps)} 
				if(as.numeric(module[strow1+j,2+k])>=0){rect(j,2.7*length(time)-k,j+1,2.7*length(time)-k-1,col=rgb(1*ratiops,gcol,bcol))}
				if(as.numeric(module[strow1+j,2+k])<0){rect(j,2.7*length(time)-k,j+1,2.7*length(time)-k-1,col=rgb(rcol,1*ratiops,bcol))}
				if(as.numeric(module[strow2+j,2+k])>=0){rationg<-as.numeric(module[strow2+j,2+k])/ulimng} 
				if(as.numeric(module[strow2+j,2+k])<0){rationg<-abs(as.numeric(module[strow2+j,2+k])/llimng)} 
				if(as.numeric(module[strow2+j,2+k])>=0){rect(j,length(time)-k,j+1,length(time)-k-1,col=rgb(1*rationg,gcol,bcol))}
				if(as.numeric(module[strow2+j,2+k])<0){rect(j,length(time)-k,j+1,length(time)-k-1,col=rgb(rcol,1*rationg,bcol))}
			}
	}
}







	


